READER_TEMPLATE = {
    "chart_type": "BarChart",
    "title": "Reader Performance",
    "subtitle": "Time and Accuracy Benchmarks",
    "description": "Performance benchmarks of different Readers that can be used off-the-shelf in Haystack. Some models are geared towards speed, while others are more performance-focused. Accuracy is measured as F1 score and speed as passages/sec (with passages of 384 tokens).  Each Reader is benchmarked using the SQuAD v2.0 development set, which contains 11866 question answer pairs. When tokenized using the BERT tokenizer and split using a sliding window approach, these become 12350 passages that are passed into the model. We set <i>max_seq_len=384</i> and <i>doc_stride=128</i>. These benchmarking tests are run using an AWS p3.2xlarge instance with a Nvidia V100 GPU with this <a href='https://github.com/deepset-ai/haystack/blob/master/test/benchmarks/reader.py'>script</a>. Please note that we are using the FARMReader class rather than the TransformersReader class. Also, the F1 measure that is reported here is in fact calculated on token level, rather than word level as is done in the official SQuAD script.",
    "bars": "horizontal",
    "columns": [
        "Model",
        "F1",
        "Speed (passages/sec)"
    ],
    "data": None
}

RETRIEVER_TEMPLATE = {
  "chart_type": "BarChart",
  "title": "Retriever Performance",
  "subtitle": "Time and Accuracy Benchmarks",
  "description": "Comparison of the speed and accuracy of different DocumentStore / Retriever combinations on 100k documents. <b>Indexing speed</b> (in docs/sec) refers to how quickly Documents can be inserted into a DocumentStore. <b>Querying speed</b> (in queries/sec) refers to the speed at which the system returns relevant Documents when presented with a query.\n\nThe dataset used is Wikipedia, split into 100 word passages (from <a href='https://github.com/facebookresearch/DPR/blob/master/data/download_data.py'>here</a>)). \n\nFor querying, we use the Natural Questions development set in combination with the wiki passages. The Document Store is populated with the 100 word passages in which the answer spans occur (i.e. gold passages) as well as a random selection of 100 word passages in which the answer spans do not occur (i.e. negative passages). We take a total of 100k gold and negative passages. Query and document embedding are generated by the <i>\"facebook/dpr-question_encoder-single-nq-base\"</i> and <i>\"facebook/dpr-ctx_encoder-single-nq-base\"</i> models. The retriever returns 10 candidates and both the recall and mAP scores are calculated on these 10.\n\nFor FAISS HNSW, we use <i>n_links=128</i>, <i>efSearch=20</i> and <i>efConstruction=80</i>. Both index and query benchmarks are performed on an AWS P3.2xlarge instance which is accelerated by an Nvidia V100 GPU.",
  "bars": "horizontal",
  "columns": [
    "Model",
    "mAP",
    "Index Speed (docs/sec)",
    "Query Speed (queries/sec)"
  ],
  "series": {
    "s0": "map",
    "s1": "time",
    "s2": "time"
  },
  "axes": {
    "label": "map",
    "time_side": "top",
    "time_label": "seconds"
  },
  "data": None
}

RETRIEVER_MAP_TEMPLATE = {
  "chart_type": "LineChart",
  "title": "Retriever Accuracy",
  "subtitle": "mAP at different number of docs",
  "description": "Here you can see how the mean avg. precision (mAP) of the retriever decays as the number of documents increases. The set up is the same as the above querying benchmark except that a varying number of negative documents are used to fill the document store.",
  "columns": [
    "n_docs",
    "BM25 / ElasticSearch",
    "DPR / ElasticSearch",
    "DPR / FAISS (flat)",
    "DPR / FAISS (HSNW)"
  ],
  "axis": [
     { "x": "Number of docs", "y": "mAP" }
   ],
  "data": None
}

RETRIEVER_SPEED_TEMPLATE = {
    "chart_type": "LineChart",
    "title": "Retriever Speed",
    "subtitle": "Query Speed at different number of docs",
    "description": "Here you can see how the query speed of different Retriever / DocumentStore combinations scale as the number of documents increases. The set up is the same as the above querying benchmark except that a varying number of negative documents are used to fill the document store.",
    "columns": [
        "n_docs",
        "BM25 / ElasticSearch",
        "DPR / ElasticSearch",
        "DPR / FAISS (flat)",
        "DPR / FAISS (HSNW)"
    ],
   "axis": [
     { "x": "Number of docs",
       "y": "Queries/sec"}
   ],
    "data": None
}